@@ -1,5 +1,8 @@
 from gensim.corpora.dictionary import Dictionary
 from chatspace import ChatSpace
+
+sys.path.append(os.path.dirname(os.path.abspath(os.path.dirname(__file__))))
+
 import fast_hangle_levenshtein
 from fast_hangle_levenshtein import LevenshteinIndex
 
@@ -8,8 +11,8 @@ import re
 import pathlib
 import pandas as pd
 
-import CustomModel
-import Jamo
+from . import CustomModel
+from . import Jamo
 
 # 사전 & 사후 spacing
 def spacer(text):
